@@ -285,6 +285,8 @@ class RouterMap():
     """
     Router Mapping Class to define and simplify your router simple CRUD
     """
+    __updated_routers = {}
+
     @classmethod
     def _get_variable(cls):
         return [cls.__dict__[v] for v in vars(cls) if type(cls.__dict__[v]) == SimpleRouter]
@@ -300,7 +302,9 @@ class RouterMap():
             for v in c._get_key_value().values():
                 allRouters[v.tablename] = v
             if c.__subclasses__():
-                allRouters.update(c._collect_simple_router())                
+                allRouters.update(c._collect_simple_router())
+        if cls == RouterMap:
+            allRouters.update(RouterMap.__updated_routers)
         return allRouters
     
     @staticmethod
@@ -322,7 +326,10 @@ class RouterMap():
         """
         Add your fastapi_simple_crud.SimpleRouter object to be generated outside of the router map
         """
-        setattr(cls, simple_router.tablename, simple_router)
+        if cls == RouterMap:
+            RouterMap.__updated_routers[simple_router.tablename] = simple_router
+        else:
+            setattr(cls, simple_router.tablename, simple_router)
 
     @classmethod
     def generate(cls, application: Optional[FastAPI] = None, session_getter: Optional[FunctionType] = None):
